Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DefaultAuthInterceptor ¶
func DefaultAuthInterceptor(ctx context.Context, req interface{}, info *grpc.UnaryServerInfo, handler grpc.UnaryHandler) (interface{}, error)
DefaultAuthInterceptor is a no-op interceptor that allows all requests.
func NewWAFInterceptor ¶
func NewWAFInterceptor(rules WAFRule) grpc.UnaryServerInterceptor
NewWAFInterceptor creates an interceptor that blocks requests containing specific substrings. This is a demonstration interceptor for testing/validating general interceptor logic. It shows how to implement custom security policies as gRPC interceptors.
Types ¶
Click to show internal directories.
Click to hide internal directories.